# solposx

`solposx` is a Python package for calculating solar position angles and comparing solar position algorithms.


## Contributing
Contributions to the repository, e.g., bug fixes, feature requests, are more than welcome!


## License
[BSD 3-clause](https://github.com/assessingsolar/solposx/blob/main/LICENSE).


```{toctree}
:maxdepth: 1
:hidden:

installation
documentation
whatsnew
```
